@@ -277,27 +277,21 @@ function TimePlot() {
         this.yAxis = d3.svg.axis().scale(this.yScale).orient("left").ticks(8)
                                   .tickSize(-(this.w - this.padding - this.padding_left), 0, 0);
 
-        var x_axis_dom = this.svg.append("g")
+        this.x_axis_dom = this.svg.append("g")
             .attr("class", "x axis")
             .attr("transform", "translate(0," + (this.h - this.padding) + ")")
             .call(this.xAxis);
 
-        var y_axis_dom = this.svg.append("g")
+        this.y_axis_dom = this.svg.append("g")
             .attr("class", "y axis")
             .attr("transform", "translate(" + this.padding_left + ",0)")
             .call(this.yAxis);
 
-        x_axis_dom.selectAll('.domain')
+        this.svg.selectAll('.domain')
             .attr('stroke', 'black')
             .attr('shape-rendering', 'crispEdges');
-        x_axis_dom.selectAll('line')
-            .attr('stroke', 'red')
-            .attr('stroke-width', '2px')
-            .attr('stroke-opacity', 1.0);
 
-        y_axis_dom.selectAll('.domain')
-            .attr('stroke', 'black')
-            .attr('shape-rendering', 'crispEdges');
+
 
         this.lines = this.svg.append("g")
             .attr("class", "lines");
@@ -420,7 +414,13 @@ function TimePlot() {
         this.svg.select(".y.axis")
             .transition()
             .duration(this.smoothness)
-            .call(this.yAxis)
+            .call(this.yAxis);
+
+        this.svg.selectAll('.axis line')
+            .style('stroke', 'lightgrey')
+            .attr('shape-rendering', 'crispEdges')
+            .attr('stroke-width', '1px')
+            .attr('stroke-opacity', 1.0);
     };
 
 
@@ -591,6 +591,12 @@ function Histogram() {
             .transition()
             .duration(this.smoothness)
             .call(this.yAxis)
+
+        this.svg.selectAll('.axis line')
+            .style('stroke', 'lightgrey')
+            .attr('shape-rendering', 'crispEdges')
+            .attr('stroke-width', '1px')
+            .attr('stroke-opacity', 1.0);
     };
 
     this.histo_y = function(d) {
@@ -811,6 +817,12 @@ function Equaliser() {
             .transition()
             .duration(this.smoothness)
             .call(this.yAxis)
+
+        this.svg.selectAll('.axis line')
+            .style('stroke', 'lightgrey')
+            .attr('shape-rendering', 'crispEdges')
+            .attr('stroke-width', '1px')
+            .attr('stroke-opacity', 1.0);
     };
 
     this.bar_y = function(d) {
